#!/bin/sh

#---help---
# Usage: genbld.sh [options] [--]
#
# Arguments:
#
# Options:
#   -t					Generate template for a new shell script
#   -x				  Activate shell tracing (set -x)
#   -h				  Print this message
#---help---

set -eu

# Prints help and exists with the specified status.
help() {
	sed -Enf /dev/fd/3 "$0" 3<<-EOF
	/^#---help---/,/^#---help---/ {
		/^#---help---/d;
		s/^#(NT)? ?//;
		p
	}
	EOF
	exit ${1:-0}
}

template() {
	local new_name="$1"
	local dz_basename="$(basename "$0")"
	sed -Enf /dev/fd/3 "$0" 3<<-EOF |
	1,/^#---template-end---/ {
		s/^(#[[:space:]]*Usage:[[:space:]]*)${dz_basename}.*$/\1${new_name} [options] [--]/
		/^#NT/d;
		s/ {8}/	/g;
		#/^#---template-end---/d;
		p
	}
	EOF
	cat
	exit 0
}

O=$(getopt "t:xh" "$@") || exit 1
eval set -- "$O"

while true; do
	case "$1" in 
	-t)	gent="YES"; new_script_name="$2"; shift 2; ;;
	-x)     shift 1; set -x;;
	-h)     help 1;;
	--)     shift; break;;
	*)      echo "Error: Unknown command-line parameter \"$1\"" >&2 && exit 1;;
	esac
done

if [ "${gent:-NO}" = "YES" ]; then
	template "$new_script_name"
	exit "$?"
fi

#---template-end---

srcdir="$(dirname "$0")"

[ -f "$srcdir"/config.ninja ] && rm "$srcdir"/config.ninja

echo "platform = $(uname -s)" > "$srcdir"/config.ninja

exec ninja
